#!/bin/bash
echo "Running configure.sh"

echo "Generating PDAS directory"
mkdir -p "${INSTALL_DIR}"
cd "${INSTALL_DIR}"

if [ ! -d pdas_instance ] ; then
    echo "Creating PRISM Data Access Server (PDAS) instance"
    eoxserver-admin.py create_instance pdas_instance

    echo "Configure PRISM Data Access Server (PDAS) instance"
    cd "pdas_instance"

    # Configure DBs
    INSTALL_DIR_ESCAPED=`echo ${INSTALL_DIR} | sed -e 's,/$,,' | sed -e 's,/,\\\&,g'`
    sed -e "s/'ENGINE': 'django.contrib.gis.db.backends.spatialite',/'ENGINE': 'django.contrib.gis.db.backends.postgis',/" -i pdas_instance/settings.py
    sed -e "s/'NAME': join(PROJECT_DIR, 'data\/config.sqlite'),/'NAME': '${DB_NAME}',/" -i pdas_instance/settings.py
    sed -e "/#'TEST_NAME': join(PROJECT_DIR, 'data\/test-config.sqlite'),/d" -i pdas_instance/settings.py
    sed -e "s/'USER': '',/'USER': '${DB_USER}',/" -i pdas_instance/settings.py
    sed -e "s/'PASSWORD': '',/'PASSWORD': '${DB_PW}',/" -i pdas_instance/settings.py
    sed -e "s/'HOST': '',/'HOST': '${DB_HOST}',/" -i pdas_instance/settings.py
    sed -e "s/'PORT': '',/'PORT': '${DB_PORT}',/" -i pdas_instance/settings.py

    # Configure instance
    sed -e "s/'disable_existing_loggers': True,/'disable_existing_loggers': False,/" -i pdas_instance/settings.py
    HANDLERS="'handlers': {\n
        'null': {\n
            'level':'DEBUG',\n
            'class':'logging.NullHandler',\n
        },\n
        'console': {\n
            'level': 'DEBUG' if DEBUG else 'INFO',\n
            'class': 'logging.StreamHandler',\n
            'formatter': 'verbose' if DEBUG else 'simple',\n
            'filters': [],\n
        },\n
    },"
    LOGGERS="'loggers': {\n
        'eoxserver': {\n
            'handlers': ['console'],\n
            'level': 'DEBUG' if DEBUG else 'INFO',\n
            'propagate': False,\n
        },
    }"
    sed -e "/^    'handlers': {$/,/^    },$/c `echo ${HANDLERS}`" -i pdas_instance/settings.py
    sed -e "/^    'loggers': {$/,/^    }$/c `echo ${LOGGERS}`" -i pdas_instance/settings.py

    sed -e "s,http_service_url=http://localhost:8000/ows,http_service_url=${APACHE_ALIAS}/ows," -i pdas_instance/conf/eoxserver.conf
    sed -e "s/resampling_method=average/resampling_method=near/" -i pdas_instance/conf/eoxserver.conf
    # TODO maxsize...

    echo "EOXS_VALIDATE_IDS_NCNAME = False" >> pdas_instance/settings.py
    echo "EOXS_OPENSEARCH_RECORD_MODEL = 'eoxserver.resources.coverages.models.Product'" >> pdas_instance/settings.py

    echo "CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.filebased.FileBasedCache',
        'LOCATION': '/var/tmp/django_cache',
    }
}" >> pdas_instance/settings.py

    sed -e "/TEMPLATE_DEBUG = DEBUG/d" -i pdas_instance/settings.py

    sed -e 's/DEBUG = True/DEBUG = False/' -i pdas_instance/settings.py

    # Further configuration
    echo "ALLOWED_HOSTS = ['*']" >> pdas_instance/settings.py
    echo "USE_X_FORWARDED_HOST = True" >> pdas_instance/settings.py
    echo "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')" >> pdas_instance/settings.py

    python manage.py migrate --noinput

    # Check if collection exits in database and initialize database only if not
    if python manage.py id check "${COLLECTION}"; then
        echo "Initialize database"

        python manage.py coveragetype import /rgbnir_definition.json --traceback

        if [ "${COLLECTION}" == "VHR_IMAGE_2018" ]; then
            echo "Initializing collection '${COLLECTION}'."

            # PL00
            python manage.py producttype create "${COLLECTION}"_Product_PL00 --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_PL00 --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1000 15000 \
                --green-range 1000 15000 \
                --blue-range 1000 15000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PL00 "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1000 15000 \
                --green-range 1000 15000 \
                --blue-range 1000 15000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PL00 "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 1000 15000 \
                --green-range 1000 15000 \
                --blue-range 1000 15000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PL00 "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            # DM02
            python manage.py producttype create "${COLLECTION}"_Product_DM02 --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_DM02 --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 250 11500 \
                --green-range 600 10000 \
                --blue-range 1300 8500 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_DM02 "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 250 11500 \
                --green-range 600 10000 \
                --blue-range 1300 8500 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_DM02 "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 400 28000 \
                --green-range 250 11500 \
                --blue-range 600 10000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_DM02 "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            # KS03
            python manage.py producttype create "${COLLECTION}"_Product_KS03 --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_KS03 --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 10000 \
                --green-range 1 10000 \
                --blue-range 1 10000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_KS03 "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 10000 \
                --green-range 1 10000 \
                --blue-range 1 10000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_KS03 "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 1 10000 \
                --green-range 1 10000 \
                --blue-range 1 10000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_KS03 "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            # KS04
            python manage.py producttype create "${COLLECTION}"_Product_KS04 --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_KS04 --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 10000 \
                --green-range 1 10000 \
                --blue-range 1 10000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_KS04 "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 10000 \
                --green-range 1 10000 \
                --blue-range 1 10000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_KS04 "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 1 10000 \
                --green-range 1 10000 \
                --blue-range 1 10000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_KS04 "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            # PH1A
            python manage.py producttype create "${COLLECTION}"_Product_PH1A --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_PH1A  --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1A "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1A "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1A "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            # PH1B
            python manage.py producttype create "${COLLECTION}"_Product_PH1B --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_PH1B --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1B "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1B "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1B "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            # SP06
            python manage.py producttype create "${COLLECTION}"_Product_SP06 --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_SP06 --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1000 20000 \
                --green-range 1000 20000 \
                --blue-range 1000 20000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_SP06 "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1000 20000 \
                --green-range 1000 20000 \
                --blue-range 1000 20000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_SP06 "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 1000 20000 \
                --green-range 1000 20000 \
                --blue-range 1000 20000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_SP06 "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            # SP07
            python manage.py producttype create "${COLLECTION}"_Product_SP07 --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_SP07 --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1000 20000 \
                --green-range 1000 20000 \
                --blue-range 1000 20000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_SP07 "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1000 20000 \
                --green-range 1000 20000 \
                --blue-range 1000 20000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_SP07 "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 1000 20000 \
                --green-range 1000 20000 \
                --blue-range 1000 20000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_SP07 "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            # SW00
            python manage.py producttype create "${COLLECTION}"_Product_SW00 --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_SW00 --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 100 1500 \
                --green-range 100 1500 \
                --blue-range 100 1500 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_SW00 "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 100 1500 \
                --green-range 100 1500 \
                --blue-range 100 1500 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_SW00 "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 100 1500 \
                --green-range 100 1500 \
                --blue-range 100 1500 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_SW00 "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            # TR00
            python manage.py producttype create "${COLLECTION}"_Product_TR00 --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_TR00 --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 3000 \
                --green-range 1 3000 \
                --blue-range 1 3000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_TR00 "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 3000 \
                --green-range 1 3000 \
                --blue-range 1 3000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_TR00 "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 1 3000 \
                --green-range 1 3000 \
                --blue-range 1 3000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_TR00 "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            python manage.py collectiontype create "${COLLECTION}"_Collection --traceback \
                --coverage-type "RGBNir" \
                --product-type "${COLLECTION}"_Product_PL00 \
                --product-type "${COLLECTION}"_Product_DM02 \
                --product-type "${COLLECTION}"_Product_KS03 \
                --product-type "${COLLECTION}"_Product_KS04 \
                --product-type "${COLLECTION}"_Product_PH1A \
                --product-type "${COLLECTION}"_Product_PH1B \
                --product-type "${COLLECTION}"_Product_SP06 \
                --product-type "${COLLECTION}"_Product_SP07 \
                --product-type "${COLLECTION}"_Product_SW00 \
                --product-type "${COLLECTION}"_Product_TR00

            # Create collections for all/Level-1/Level-3 products
            python manage.py collection create "${COLLECTION}" --type "${COLLECTION}"_Collection --traceback
            python manage.py collection create "${COLLECTION}_Level_1" --type "${COLLECTION}"_Collection --traceback
            python manage.py collection create "${COLLECTION}_Level_3" --type "${COLLECTION}"_Collection --traceback

            # Register mask type
            python manage.py masktype create --validity "${COLLECTION}"_Product_PL00 validity
            python manage.py masktype create --validity "${COLLECTION}"_Product_DM02 validity
            python manage.py masktype create --validity "${COLLECTION}"_Product_KS03 validity
            python manage.py masktype create --validity "${COLLECTION}"_Product_KS04 validity
            python manage.py masktype create --validity "${COLLECTION}"_Product_PH1A validity
            python manage.py masktype create --validity "${COLLECTION}"_Product_PH1B validity
            python manage.py masktype create --validity "${COLLECTION}"_Product_SP06 validity
            python manage.py masktype create --validity "${COLLECTION}"_Product_SP07 validity
            python manage.py masktype create --validity "${COLLECTION}"_Product_SW00 validity
            python manage.py masktype create --validity "${COLLECTION}"_Product_TR00 validity

        elif [ "${COLLECTION}" == "Emergency" ]; then
            echo "Initializing collection '${COLLECTION}'."

            # CS00
            # CS01
            # CS02
            # CS03
            # CS04
            # DM01
            # EQ02
            # EW01
            # EW02
            # EW03
            # GE01
            # GY01
            # IK02
            # RE00
            # RS02
            # SP04
            # SP05
            # TX01

            # DM02
            # KS03
            # SP06
            # SP07

            # PH1A
            python manage.py producttype create "${COLLECTION}"_Product_PH1A --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_PH1A  --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1A "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1A "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1A "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            # PH1B
            python manage.py producttype create "${COLLECTION}"_Product_PH1B --traceback \
                --coverage-type "RGBNir"
            python manage.py browsetype create "${COLLECTION}"_Product_PH1B --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1B "TRUE_COLOR" --traceback \
                --red "red" \
                --green "green" \
                --blue "blue" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1B "FALSE_COLOR" --traceback \
                --red "nir" \
                --green "red" \
                --blue "green" \
                --red-range 1 2000 \
                --green-range 1 2000 \
                --blue-range 1 2000 \
                --red-nodata 0 \
                --green-nodata 0 \
                --blue-nodata 0
            python manage.py browsetype create "${COLLECTION}"_Product_PH1B "NDVI" --traceback \
                --grey "(nir-red)/(nir+red)" --grey-range -1 1

            python manage.py collectiontype create "${COLLECTION}"_Collection --traceback \
                --coverage-type "RGBNir" \
                --product-type "${COLLECTION}"_Product_PH1A \
                --product-type "${COLLECTION}"_Product_PH1B

            python manage.py collection create "${COLLECTION}" --type "${COLLECTION}"_Collection --traceback

        else
            echo "Provided collection '${COLLECTION}' not valid."
       fi

        python manage.py storageauth create auth-cloud-ovh "${OS_AUTH_URL_SHORT}" \
            --type keystone \
            -p auth-version "${ST_AUTH_VERSION}" \
            -p identity-api-version="${ST_AUTH_VERSION}" \
            -p username "${OS_USERNAME}" \
            -p password "${OS_PASSWORD}" \
            -p tenant-name "${OS_TENANT_NAME}" \
            -p tenant-id "${OS_TENANT_ID}" \
            -p region-name "${OS_REGION_NAME}"

        for bucket in "data10" "data11" "data12" "data13" "data14" "data15" "data16" "data17" "data18" "data20" "data21" "data22" "data23" "data24" "data25" "data26"; do
            python manage.py storage create \
                ${bucket} ${bucket} \
                --type swift \
                --storage-auth auth-cloud-ovh
        done

        echo "Creating admin user"
        python manage.py shell -c "from django.contrib.auth.models import User; User.objects.create_superuser('${DJANGO_USER}', '${DJANGO_MAIL}', '${DJANGO_PASSWORD}')"

    else
        echo "Using existing database"
    fi

    # Collect static files
    python manage.py collectstatic --noinput

    chmod g+w -R .
    chgrp users -R .
else
    echo "Using existing PRISM Data Access Server (PDAS) instance"
fi
